CompressionAlgorithm enum

Represents the available compression algorithms for message payloads.

This enum provides options for enabling or disabling compression, as well as choosing between base64-encoded or binary-compressed formats.

Inheritance
Available extensions

Values

NONE → const CompressionAlgorithm

No compression is applied to the message payload.

ZLIB_BASE64 → const CompressionAlgorithm

Compression is applied using the ZLIB algorithm, and the result is base64-encoded for transport over utf8-based protocol.

ZLIB_BINARY → const CompressionAlgorithm

Compression is applied using the ZLIB algorithm, and the result is transmitted as raw binary for highest compression efficiency.

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<CompressionAlgorithm>
A constant List of the values in this enum, in order of their declaration.