MigratoryDataMessage class

Represent a MigratoryData message.

Constructors

MigratoryDataMessage(String subject, Uint8List content, {String closure = "", QoS qos = QoS.GUARANTEED, bool retained = true, String replySubject = "", bool compression = false, CompressionAlgorithm compressionAlgorithm = CompressionAlgorithm.NONE})
//// Create a MigratoryDataMessage object.

Properties

closure ↔ String
getter/setter pair
compressedContent ↔ Uint8List?
getter/setter pair
compression ↔ bool
getter/setter pair
compressionAlgorithm ↔ CompressionAlgorithm
getter/setter pair
content ↔ Uint8List
getter/setter pair
epoch ↔ int
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
messageType ↔ MessageType
getter/setter pair
qos ↔ QoS
getter/setter pair
replySubject ↔ String
getter/setter pair
retained ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
seq ↔ int
getter/setter pair
subject ↔ String
getter/setter pair

Methods

getClosure() → String
//// Get the closure of the message.
getCompressionAlgorithm() → CompressionAlgorithm
Returns the compression algorithm currently configured for the message.
getContent() → Uint8List
//// Get the content of the message.
getEpoch() → int
getMessageType() → MessageType
//// Get the MessageType of the message.
getQos() → QoS
//// Get the QoS level of the message.
getReplySubject() → String
//// Get the reply subject of the message.
getSeq() → int
getSubject() → String
//// Get the subject of the message.
isCompressed() → bool
Indicates whether the message should be or was compressed.
isRetained() → bool
//// Indicate whether or not the message should be/was retained by the server.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setCompressionToNone() → void
toString() → String
Return a string representation of the message.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited